Stan Math Library: stan/math/prim/mat/fun/multiply.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multiply.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <boost/type_traits/is_arithmetic.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C, typename T >
boost::enable_if_c< boost::is_arithmetic< T >::value, Eigen::Matrix< double, R, C > >::type | stan::math::multiply (const Eigen::Matrix< double, R, C > &m, T c)
| Return specified matrix multiplied by specified scalar. More...
template<int R, int C, typename T >
boost::enable_if_c< boost::is_arithmetic< T >::value, Eigen::Matrix< double, R, C > >::type | stan::math::multiply (T c, const Eigen::Matrix< double, R, C > &m)
| Return specified scalar multiplied by specified matrix. More...
template<int R1, int C1, int R2, int C2>
Eigen::Matrix< double, R1, C2 > | stan::math::multiply (const Eigen::Matrix< double, R1, C1 > &m1, const Eigen::Matrix< double, R2, C2 > &m2)
| Return the product of the specified matrices. More...
template<int C1, int R2>
double | stan::math::multiply (const Eigen::Matrix< double, 1, C1 > &rv, const Eigen::Matrix< double, R2, 1 > &v)
| Return the scalar product of the specified row vector and specified column vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.